# nspyre
[![GitHub license](https://img.shields.io/github/license/nspyre-org/nspyre)](https://github.com/nspyre-org/nspyre/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/nspyre/badge/?version=latest)](https://nspyre.readthedocs.io/en/latest/?badge=latest)

Networked Scientific Python Research Environment

See https://nspyre.readthedocs.io/en/develop/

## Installation

```
conda install -c conda-forge nspyre
```
